import 'package:args/args.dart';
import 'package:logging/logging.dart';
import 'package:shelf/shelf.dart';
import 'package:shelf/shelf_io.dart' as shelf;
import 'package:shelf_static/shelf_static.dart';

import 'logger.dart';
import 'shelf_cors.dart' as shelf_cors;

const _hostname = '0.0.0.0';

Future main(List<String> args) async {
  initLog();

  final ArgParser argParser = ArgParser();
  argParser.addOption(
    'directory',
    abbr: 'd',
    defaultsTo: '',
    help: 'fair project directory',
  );
  var result = argParser.parse(args);
  var directory = result.arguments.isNotEmpty ? result.arguments.last : '';
  startServer(directory);
}

void startServer(String dir) async {
  try {
    var pipeline = Pipeline()
        .addMiddleware(logRequests())
        .addMiddleware(_createCustomCorsHeadersMiddleware());
    final fairDirHandler = pipeline.addHandler(
        createStaticHandler('$dir/build/fair', listDirectories: true));
    await shelf.serve(fairDirHandler, _hostname, 8080).then((server) {
      Logger.root
          .info('Serving at http://${server.address.host}:${server.port}');
    });
  } catch (e) {
    Logger.root.info(e.toString());
    throw e;
  }
}

Middleware _createCustomCorsHeadersMiddleware() {
  return shelf_cors.createCorsHeadersMiddleware(corsHeaders: <String, String>{
    'Access-Control-Allow-Origin': '*',
    'Access-Control-Allow-Methods': 'GET, POST, OPTIONS',
    'Access-Control-Max-Age': '31536000',
    'Access-Control-Allow-Headers':
        'Origin, X-Requested-With, Content-Type, Accept, x-goog-api-client, device_id, project_name',
    'X-Frame-Options': '*'
  });
}
