// @dart = 2.8

import 'dart:async';
import 'dart:convert';
import 'dart:io';

import '../base/common.dart';
import '../globals.dart';
import '../runner/faircli_command.dart';
import '../util/util.dart';

class ServerCommand extends FaircliCommand {
  ServerCommand() {
    argParser.addOption(
      'description',
      defaultsTo: 'server',
      help: 'The description to start a local server for download fair patch.',
    );
    argParser.addOption(
      'directory',
      abbr: 'd',
      defaultsTo: '',
      help: 'fair project directory',
    );
  }

  @override
  final String name = 'server';

  @override
  final String description = 'Start a local server for download Fair patch';

  @override
  Future<FaircliCommandResult> runCommand() async {
    String currentPath = argResults['directory'];
    if (currentPath.isEmpty) {
      currentPath = localFileSystem.currentDirectory.path;
    }
    var fileRoot = userRootPath();
    var fairServerDir = fs.path.join(fileRoot, 'FairServer');
    var toolDir = fs.path.join(fairServerDir, 'bin');
    var toolPath = fs.path.join(toolDir, 'server.exe');

    try {
      cliPrint('Start local fair server...');
      Process process;
      try {
        process = await Process.start(toolPath, ['-d', currentPath],
            workingDirectory: currentPath);
      } catch (e) {
        var fairServerDirCopy = fs.path.join(userHomePath(), 'FairServer');
        await copyPath(fairServerDir, fairServerDirCopy);
        var pubGetResult = Process.runSync('dart', ['pub', 'get'],
            workingDirectory: fairServerDirCopy);
        if (pubGetResult.exitCode != 0) {
          throwToolExit(
              'Failed to start local server: pub get error >>> stdout: ${pubGetResult.stdout} \n >>> stdout :${pubGetResult.stderr}');
        }
        process = await Process.start(
            'dart',
            [
              fs.path.join(fairServerDirCopy, 'bin', 'server.dart'),
              '-d',
              currentPath
            ],
            workingDirectory: currentPath);
      }
      process.stdout
          .transform<String>(utf8.decoder)
          .transform<String>(const LineSplitter())
          .listen((String line) => cliPrint('>>>>>> $line'));
      process.stderr.listen(stderr.add);
      await process.exitCode;
      Process.killPid(process.pid);
    } catch (e) {
      throwToolExit('Failed to start local server: $e');
    }
    return null;
  }
}
